@@ -1,5 +1,5 @@
 // Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -30,7 +30,14 @@ public slots:
     void savePathScreenshot(const QString &path);
     void startScreenshotFor3rd(const QString &path);
     void initLaunchMode(const QString &launchmode);
+
+    /**
+     * @brief fullScreenRecord 快捷启动全屏录制,文件路径
+     */
+    void fullScreenRecord(QString fileName = "");
+
     Q_SCRIPTABLE void stopRecord();
+    Q_SCRIPTABLE void stopApp();
     Q_SCRIPTABLE QString getRecorderNormalIcon();
 signals:
     Q_SCRIPTABLE void RecorderState(const bool isStart); // true begin recorder; false stop recorder;
