@@ -24,10 +24,12 @@ QMap<QString, QCursor> BaseUtils::m_shapesCursor = QMap<QString, QCursor>();
 
 QCursor BaseUtils::setCursorShape(QString cursorName, int colorIndex)
 {
+    qCDebug(dsrApp) << "setCursorShape() called with cursorName:" << cursorName << ", colorIndex:" << colorIndex;
 
     QString cursorNameString = cursorName;
     if (cursorName == "pen") {
         cursorNameString = QString("%1%2").arg(cursorName).arg(colorIndex);
+        qCDebug(dsrApp) << "Adjusted cursorNameString for pen:" << cursorNameString;
     }
 
     if (BaseUtils::m_shapesCursor.find(cursorNameString) != BaseUtils::m_shapesCursor.end()) {
@@ -35,10 +37,6 @@ QCursor BaseUtils::setCursorShape(QString cursorName, int colorIndex)
         return BaseUtils::m_shapesCursor.value(cursorNameString);
     }
 
-
-
-
-
     QCursor customShape = QCursor();
     qreal ration = qApp->devicePixelRatio();
     qCDebug(dsrApp) << "Device pixel ratio:" << ration;
@@ -49,43 +47,50 @@ QCursor BaseUtils::setCursorShape(QString cursorName, int colorIndex)
         if (ration <= 1) {
             startPix = QIcon(":/mouse_style/shape/start_mouse.svg").pixmap(START_SIZE);
             customShape = QCursor(startPix, 8, 8);
+            qCDebug(dsrApp) << "Loaded start_mouse.svg for ratio <= 1.";
         } else {
             startPix = QIcon(":/mouse_style/shape/start_mouse@2x.svg").pixmap(START_SIZE);
             customShape = QCursor(startPix, int(8 * ration), int(8 * ration));
+            qCDebug(dsrApp) << "Loaded start_mouse@2x.svg for ratio > 1.";
         }
-
     } else if (cursorName == "rotate") {
-        qCDebug(dsrApp) << "Creating rotate cursor";
+        qCDebug(dsrApp) << "Creating rotate cursor.";
         QPixmap rotateCursor  = QIcon(":/mouse_style/shape/rotate_mouse.svg").pixmap(ARROW_SIZE);
         rotateCursor.setDevicePixelRatio(ration);
 
         customShape = QCursor(rotateCursor, int(10 * ration), int(10 * ration));
     } else if (cursorName == "rectangle") {
+        qCDebug(dsrApp) << "Creating rectangle cursor.";
         QPixmap rectCursor  = QIcon(":/mouse_style/shape/rect_mouse.svg").pixmap(RECT_SIZE);
         rectCursor.setDevicePixelRatio(ration);
 
         customShape = QCursor(rectCursor, 0, int(1 * ration));
     } else if (cursorName == "oval") {
+        qCDebug(dsrApp) << "Creating oval cursor.";
         QPixmap ovalCursor  = QIcon(":/mouse_style/shape/ellipse_mouse.svg").pixmap(RECT_SIZE);
         ovalCursor.setDevicePixelRatio(ration);
 
         customShape = QCursor(ovalCursor, 0, int(1 * ration));
     } else if (cursorName == "arrow") {
+        qCDebug(dsrApp) << "Creating arrow cursor.";
         QPixmap arrowCursor  = QIcon(":/mouse_style/shape/arrow_mouse.svg").pixmap(ARROW_SIZE);
         arrowCursor.setDevicePixelRatio(ration);
 
         customShape = QCursor(arrowCursor, int(5 * ration), int(5 * ration));
     } else if (cursorName == "text") {
+        qCDebug(dsrApp) << "Creating text cursor.";
         QPixmap textCursor  = QIcon(":/mouse_style/shape/text_mouse.svg").pixmap(TEXT_SIZE);
         textCursor.setDevicePixelRatio(ration);
 
         customShape = QCursor(textCursor, int(5 * ration), int(5 * ration));
     } else if (cursorName == "pen") {
+        qCDebug(dsrApp) << "Creating pen cursor.";
         QPixmap colorPic = QIcon(QString(":/color_pen/color%1.svg").arg(colorIndex)).pixmap(COLORPEN_SIZE);
         colorPic.setDevicePixelRatio(ration);
 
         customShape = QCursor(colorPic,  int(5 * ration), int(22 * ration));
     } else if (cursorName == "line") {
+        qCDebug(dsrApp) << "Creating line cursor.";
         QPixmap lineCursor  = QIcon(":/mouse_style/shape/line_mouse.svg").pixmap(ARROW_SIZE);
         lineCursor.setDevicePixelRatio(ration);
 
@@ -99,12 +104,16 @@ QCursor BaseUtils::setCursorShape(QString cursorName, int colorIndex)
 
 int BaseUtils::stringWidth(const QFont &f, const QString &str)
 {
+    qCDebug(dsrApp) << "stringWidth() called with font and string:" << str;
     QFontMetrics fm(f);
-    return fm.boundingRect(str).width();
+    int width = fm.boundingRect(str).width();
+    qCDebug(dsrApp) << "Calculated string width:" << width;
+    return width;
 }
 
 QColor BaseUtils::colorIndexOf(int index)
 {
+    qCDebug(dsrApp) << "colorIndexOf() called with index:" << index;
     QList<QColor> colorList;
     colorList.append(QColor("#000000"));
     colorList.append(QColor("#7D7D7D"));
@@ -123,6 +132,7 @@ QColor BaseUtils::colorIndexOf(int index)
 
 int BaseUtils::colorIndex(QColor color)
 {
+    qCDebug(dsrApp) << "colorIndex() called with color:" << color;
     QList<QColor> colorList;
     colorList.append(QColor("#000000"));
     colorList.append(QColor("#7D7D7D"));
@@ -148,6 +158,7 @@ bool BaseUtils::isValidFormat(QString suffix)
     if (!isValid) {
         qCWarning(dsrApp) << "Invalid format detected:" << suffix;
     }
+    qCDebug(dsrApp) << "Format" << suffix << "is valid:" << isValid;
     return isValid;
 }
 
@@ -164,6 +175,7 @@ bool BaseUtils::isCommandExist(QString command)
     proc->waitForFinished(1000);
     int ret = proc->exitCode() == 0;
     delete proc;
+    proc = nullptr;
     
     if (!ret) {
         qCWarning(dsrApp) << "Command not found:" << command;
