@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="de">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -25,6 +23,17 @@ oder drücken Sie die Tastenkombination erneut, um die Aufnahme zu stoppen</tran
         <translation>Wird aufgenommen</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Record</source>
+        <translation>Aufnehmen</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Bildschirmaufnahme</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -95,17 +104,21 @@ oder drücken Sie die Tastenkombination erneut, um die Aufnahme zu stoppen</tran
         <source>Scrollshot</source>
         <translation>Bildlaufaufnahme</translation>
     </message>
-    <message>
-        <source>Open Folder</source>
-        <translation>Ordner öffnen</translation>
-    </message>
     <message>
         <source>Pin Screenshots</source>
         <translation>Bildschirmfotos anheften</translation>
     </message>
     <message>
         <source>deepin-screen-recorder</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open Folder</source>
+        <translation>Ordner öffnen</translation>
+    </message>
+    <message>
+        <source>Screenshot finished and copy to clipboard</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -134,22 +147,22 @@ oder drücken Sie die Tastenkombination erneut, um die Aufnahme zu stoppen</tran
     <name>QuickPanelWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">Bildschirmaufnahme</translation>
+        <translation>Bildschirmaufnahme</translation>
     </message>
     <message>
         <source>Record</source>
-        <translation type="unfinished">Aufnehmen</translation>
+        <translation>Aufnehmen</translation>
     </message>
 </context>
 <context>
     <name>RecordIconWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">Bildschirmaufnahme</translation>
+        <translation>Bildschirmaufnahme</translation>
     </message>
     <message>
         <source>Recording</source>
-        <translation type="unfinished">Wird aufgenommen</translation>
+        <translation>Wird aufgenommen</translation>
     </message>
 </context>
 <context>
@@ -334,6 +347,10 @@ oder drücken Sie die Tastenkombination erneut, um die Aufnahme zu stoppen</tran
         <source>Display shortcuts</source>
         <translation>Tastenkombinationen anzeigen</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>Ton</translation>
+    </message>
     <message>
         <source>Keystroke</source>
         <translation>Tastendruck</translation>
@@ -354,6 +371,10 @@ oder drücken Sie die Tastenkombination erneut, um die Aufnahme zu stoppen</tran
         <source>Start/Recording</source>
         <translation>Start/Aufnahme</translation>
     </message>
+    <message>
+        <source>Mouse</source>
+        <translation>Maus</translation>
+    </message>
     <message>
         <source>Tools</source>
         <translation>Werkzeuge</translation>
@@ -370,26 +391,18 @@ oder drücken Sie die Tastenkombination erneut, um die Aufnahme zu stoppen</tran
         <source>Pin screenshots</source>
         <translation>Bildschirmfotos anheften</translation>
     </message>
-    <message>
-        <source>Start scrollshot</source>
-        <translation>Bildlaufaufnahme starten</translation>
-    </message>
     <message>
         <source>Start OCR</source>
         <translation>OCR starten</translation>
     </message>
+    <message>
+        <source>Start scrollshot</source>
+        <translation>Bildlaufaufnahme starten</translation>
+    </message>
     <message>
         <source>Arrow</source>
         <translation>Pfeil</translation>
     </message>
-    <message>
-        <source>Sound</source>
-        <translation>Ton</translation>
-    </message>
-    <message>
-        <source>Mouse</source>
-        <translation>Maus</translation>
-    </message>
 </context>
 <context>
     <name>ShotStartPlugin</name>
@@ -402,7 +415,7 @@ oder drücken Sie die Tastenkombination erneut, um die Aufnahme zu stoppen</tran
     <name>ShotStartRecordPlugin</name>
     <message>
         <source>Record</source>
-        <translation type="unfinished">Aufnehmen</translation>
+        <translation>Aufnehmen</translation>
     </message>
 </context>
 <context>
@@ -410,40 +423,75 @@ oder drücken Sie die Tastenkombination erneut, um die Aufnahme zu stoppen</tran
     <message>
         <source>Rectangle
 Press and hold Shift to draw a square</source>
-        <translation type="unfinished"></translation>
+        <translation>Rechteck
+Umschalttaste gedrückt halten, um ein Rechteck zu zeichnen</translation>
     </message>
     <message>
         <source>Ellipse
 Press and hold Shift to draw a circle</source>
-        <translation type="unfinished"></translation>
+        <translation>Ellipse
+Umschalttaste gedrückt halten, um eine Ellipse zu zeichnen</translation>
     </message>
     <message>
         <source>Brush
 Press and hold Shift to draw a straight line</source>
-        <translation type="unfinished"></translation>
+        <translation>Pinsel
+Umschalttaste gedrückt halten, um eine gerade Linie zu zeichnen</translation>
     </message>
     <message>
         <source>Adjust blur strength (Scroll to adjust it)</source>
-        <translation type="unfinished"></translation>
+        <translation>Verpixel-Größe einstellen (durch Scrollen)</translation>
     </message>
     <message>
         <source>Adjust brush size (Scroll to adjust it)</source>
-        <translation type="unfinished"></translation>
+        <translation>Pinselgröße einstellen (durch Scrollen)</translation>
     </message>
     <message>
         <source>Adjust text size (Scroll to adjust it)</source>
-        <translation type="unfinished"></translation>
+        <translation>Textgröße einstellen (durch Scrollen)</translation>
+    </message>
+</context>
+<context>
+    <name>StartTooltip</name>
+    <message>
+        <source>Click or drag to
+select the area to record</source>
+        <translation>Klicken oder ziehen, um den Bildschirmbereich auszuwählen, der aufgenommen wird.</translation>
     </message>
 </context>
 <context>
     <name>SubToolWidget</name>
     <message>
-        <source>Microphone</source>
-        <translation>Mikrofon</translation>
+        <source>Show keystroke (K)</source>
+        <translation>Tastendruck anzeigen (K)</translation>
     </message>
     <message>
-        <source>Options</source>
-        <translation>Optionen</translation>
+        <source>Hide Keystroke (K)</source>
+        <translation>Tastendruck ausblenden (K)</translation>
+    </message>
+    <message>
+        <source>Show Keystroke (K)</source>
+        <translation>Tastendruck anzeigen (K)</translation>
+    </message>
+    <message>
+        <source>Turn on camera (C)</source>
+        <translation>Kamera einschalten (C)</translation>
+    </message>
+    <message>
+        <source>Turn off camera (C)</source>
+        <translation>Kamera ausschalten (C)</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Bildschirmaufnahme</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Einstellungen</translation>
+    </message>
+    <message>
+        <source>Settings (F3)</source>
+        <translation>Einstellungen (F3)</translation>
     </message>
     <message>
         <source>Format:</source>
@@ -457,6 +505,14 @@ Press and hold Shift to draw a straight line</source>
         <source>MP4</source>
         <translation>MP4</translation>
     </message>
+    <message>
+        <source>MKV</source>
+        <translation>MKV</translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation>webm</translation>
+    </message>
     <message>
         <source>FPS:</source>
         <translation>BpS:</translation>
@@ -481,6 +537,30 @@ Press and hold Shift to draw a straight line</source>
         <source>30 fps</source>
         <translation>30 BpS</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>Ton</translation>
+    </message>
+    <message>
+        <source>Microphone</source>
+        <translation>Mikrofon</translation>
+    </message>
+    <message>
+        <source>System audio</source>
+        <translation>System-Audio</translation>
+    </message>
+    <message>
+        <source>Options</source>
+        <translation>Optionen</translation>
+    </message>
+    <message>
+        <source>Show pointer</source>
+        <translation>Zeiger anzeigen</translation>
+    </message>
+    <message>
+        <source>Show click</source>
+        <translation>Klick anzeigen</translation>
+    </message>
     <message>
         <source>Save to</source>
         <translation>Speichern unter</translation>
@@ -490,56 +570,36 @@ Press and hold Shift to draw a straight line</source>
         <translation>Schreibtisch</translation>
     </message>
     <message>
-        <source>Pictures</source>
-        <translation>Bilder</translation>
+        <source>Videos</source>
+        <translation>Videos</translation>
     </message>
     <message>
-        <source>Folder</source>
-        <translation>Ordner</translation>
+        <source>Rectangle (R)
+Press and hold Shift to draw a square</source>
+        <translation>Rechteck (R)
+Umschalttaste gedrückt halten, um ein Rechteck zu zeichnen</translation>
     </message>
     <message>
-        <source>Format</source>
-        <translation>Format</translation>
+        <source>Ellipse (O)
+Press and hold Shift to draw a circle</source>
+        <translation>Ellipse (O)
+Umschalttaste gedrückt halten, um einen Kreis zu zeichnen</translation>
     </message>
     <message>
-        <source>PNG</source>
-        <translation>PNG</translation>
+        <source>Line (L)
+Press and hold Shift to draw a vertical or horizontal line</source>
+        <translation>Linie (L)
+Umschalttaste gedrückt halten, um eine vertikale oder horizontale Linie zu zeichnen</translation>
     </message>
     <message>
-        <source>JPG</source>
-        <translation>JPG</translation>
+        <source>Arrow (X)
+Press and hold Shift to draw a vertical or horizontal arrow</source>
+        <translation>Pfeil (X)
+Umschalttaste gedrückt halten, um einen vertikalen oder horizontalen Pfeil zu zeichnen</translation>
     </message>
     <message>
-        <source>BMP</source>
-        <translation>BMP</translation>
-    </message>
-    <message>
-        <source>MKV</source>
-        <translation>MKV</translation>
-    </message>
-    <message>
-        <source>Clipboard</source>
-        <translation>Zwischenablage</translation>
-    </message>
-    <message>
-        <source>Show pointer</source>
-        <translation>Zeiger anzeigen</translation>
-    </message>
-    <message>
-        <source>Extract Text</source>
-        <translation>Text extrahieren</translation>
-    </message>
-    <message>
-        <source>Show keystroke (K)</source>
-        <translation>Tastendruck anzeigen (K)</translation>
-    </message>
-    <message>
-        <source>Settings</source>
-        <translation>Einstellungen</translation>
-    </message>
-    <message>
-        <source>Settings (F3)</source>
-        <translation>Einstellungen (F3)</translation>
+        <source>Pencil (P)</source>
+        <translation>Stift (P)</translation>
     </message>
     <message>
         <source>Blur (B)</source>
@@ -557,29 +617,53 @@ Press and hold Shift to draw a straight line</source>
         <source>Extract text (Alt+O）</source>
         <translation>Text extrahieren (Alt+O）</translation>
     </message>
-    <message>
-        <source>Undo (Ctrl+Z)</source>
-        <translation>Rückgängig (Strg+Z)</translation>
-    </message>
-    <message>
-        <source>Screenshot</source>
-        <translation>Bildschirmaufnahme</translation>
-    </message>
     <message>
         <source>Pin screenshots (Alt+P）</source>
         <translation>Bildschirmfotos anheften (Alt+P）</translation>
     </message>
+    <message>
+        <source>Undo (Ctrl+Z)</source>
+        <translation>Rückgängig (Strg+Z)</translation>
+    </message>
     <message>
         <source>Record</source>
         <translation>Aufnehmen</translation>
     </message>
     <message>
-        <source>Pencil (P)</source>
-        <translation>Stift (P)</translation>
+        <source>Clipboard</source>
+        <translation>Zwischenablage</translation>
     </message>
     <message>
-        <source>Turn on camera (C)</source>
-        <translation>Kamera einschalten (C)</translation>
+        <source>Pictures</source>
+        <translation>Bilder</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Ordner</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Beim Speichern einen Pfad festlegen</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Beim Speichern den Pfad ändern</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Format</translation>
+    </message>
+    <message>
+        <source>PNG</source>
+        <translation>PNG</translation>
+    </message>
+    <message>
+        <source>JPG</source>
+        <translation>JPG</translation>
+    </message>
+    <message>
+        <source>BMP</source>
+        <translation>BMP</translation>
     </message>
     <message>
         <source>Border Effects</source>
@@ -589,77 +673,21 @@ Press and hold Shift to draw a straight line</source>
         <source>None</source>
         <translation>Keine</translation>
     </message>
-    <message>
-        <source>Turn off camera (C)</source>
-        <translation>Kamera ausschalten (C)</translation>
-    </message>
-    <message>
-        <source>Hide Keystroke (K)</source>
-        <translation>Tastendruck ausblenden (K)</translation>
-    </message>
-    <message>
-        <source>Show Keystroke (K)</source>
-        <translation>Tastendruck anzeigen (K)</translation>
-    </message>
-    <message>
-        <source>webm</source>
-        <translation>webm</translation>
-    </message>
-    <message>
-        <source>Videos</source>
-        <translation>Videos</translation>
-    </message>
-    <message>
-        <source>Rectangle (R)
-Press and hold Shift to draw a square</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Ellipse (O)
-Press and hold Shift to draw a circle</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Line (L)
-Press and hold Shift to draw a vertical or horizontal line</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Arrow (X)
-Press and hold Shift to draw a vertical or horizontal arrow</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Shadow</source>
-        <translation type="unfinished"></translation>
+        <translation>Schatten</translation>
     </message>
     <message>
         <source>Border</source>
-        <translation type="unfinished"></translation>
+        <translation>Rand</translation>
     </message>
     <message>
         <source>Device</source>
-        <translation type="unfinished"></translation>
+        <translation>Gerät</translation>
     </message>
     <message>
-        <source>Sound</source>
-        <translation>Ton</translation>
-    </message>
-    <message>
-        <source>System audio</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Show click</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Change the path on save</source>
-        <translation type="unfinished"></translation>
+        <source>Extract Text</source>
+        <translation>Text extrahieren</translation>
     </message>
 </context>
 <context>
@@ -691,4 +719,11 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <translation>Beenden</translation>
     </message>
 </context>
-</TS>
+<context>
+    <name>VoiceRecordProcess</name>
+    <message>
+        <source>New recording</source>
+        <translation>Neue Aufnahme</translation>
+    </message>
+</context>
+</TS>
\ No newline at end of file
